<?php

namespace App\Controller;

use Exception;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Http\Authentication\AuthenticationUtils;
use Symfony\Contracts\Translation\TranslatorInterface;

/**
 * Controller about security (login / logout)
 *
 * @package App\Controller
 */
class SecurityController extends AbstractController {
    /**
     * Show login form
     *
     * @param TranslatorInterface $translator Interface for translation
     * @param AuthenticationUtils $authenticationUtils Helper for authentication information
     *
     * @return Response Page response
     *
     * @Route("/sign-in")
     */
    public function sign_in (TranslatorInterface $translator, AuthenticationUtils $authenticationUtils): Response {
        $error = $authenticationUtils->getLastAuthenticationError();
        if ($error !== null) {
            $this->addFlash('error',  $translator->trans($error->getMessageKey(), $error->getMessageData(), 'security'));
        }

        return $this->render(
            'security/sign-in.html.twig',
            [
                'username' => $authenticationUtils->getLastUsername(),
            ]
        );
    }

    /**
     * *Perform* logout
     *
     * @throws Exception When firewall failed and this method is *really* called
     *
     * @Route("/sign-out")
     */
    public function sign_out () {
        throw new Exception('This method can be blank - it will be intercepted by the logout key on your firewall');
    }
}
